<?php
/**
 * The general interface for all other database wrappers
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2013 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface DatabaseWrapper extends FrameworkInterface {
	/**
	 * Getter for index key
	 *
	 * @return	$indexKey	Index key
	 */
	function getIndexKey();

	/**
	 * Getter for last exception
	 *
	 * @return	$lastException	Last exception or NULL if none occured
	 */
	function getLastException();

	/**
	 * Do a "select" query on the current table with the given search criteria and
	 * store it in cache for later usage
	 *
	 * @param	$criteriaInstance	An instance of a Criteria class
	 * @param	$onlyKeys			Only use these keys for a cache key
	 * @return	$resultInstance		An instance of a database result class
	 */
	function doSelectByCriteria(Criteria $criteriaInstance, array $onlyKeys = array());

	/**
	 * Count the numbers of rows we shall receive
	 *
	 * @param	$criteriaInstance	An instance of a Criteria class
	 * @param	$onlyKeys			Only use these keys for a cache key
	 * @return	$numRows			Numbers of rows of database entries
	 */
	function doSelectCountByCriteria(Criteria $criteriaInstance, $onlyKeys =  array());

	/**
	 * Getter for primary key used in wrapped table
	 *
	 * @return	$primaryKey		Primary key used in wrapped table
	 */
	function getPrimaryKeyValue();
}

// [EOF]
?>
